<?php
header('Content-Type: application/json'); // Set header for JSON response

include '../db.php'; // Include the database connection
include '../component/current_time.php'; // Include the current time function

// Get the POST data
$data = json_decode(file_get_contents("php://input"));
$name = $data->name ?? '';
$email = $data->email ?? '';
$number = $data->number ?? '';
$password = $data->password ?? '';
$balance = $data->balance ?? 0.0;
$device_id = $data->device_id ?? '';
$country = $data->country ?? '';
$country_iso = $data->country_iso ?? '';
$country_code = $data->country_code ?? '';

// Validate required fields
if (empty($name) || empty($email) || empty($number) || empty($password)) {
    echo json_encode(['message' => 'error', 'error' => 'All fields are required.']);
    exit();
}

// Check if the email already exists
$result = $conn->query("SELECT id FROM data_user WHERE email = '$email'");
if ($result->num_rows > 0) {
    echo json_encode(['message' => 'error', 'error' => 'Email already registered.']);
    exit();
}

// Generate the token and hash the password
$token = bin2hex(random_bytes(16)); // Generates a random token
$hashed_password = password_hash($password, PASSWORD_DEFAULT);

// Set additional fields
$joinAt = getCurrentTime(); // Get real-time from included function
$role = 'user'; // Default role
$status = 'active'; // Default status

// Insert the user into the database with initial userId as 0
$stmt = $conn->prepare("INSERT INTO data_user (user_id, name, number, email, password, token, balance, joinAt, role, device_id, status, country, country_iso, country_code) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
$userId = 0; // Set initial userId to 0
$stmt->bind_param("isssssdsssssss", $userId, $name, $number, $email, $hashed_password, $token, $balance, $joinAt, $role, $device_id, $status, $country, $country_iso, $country_code);

if ($stmt->execute()) {
    // After successful insertion, query the user id based on the email
    $query = $conn->query("SELECT id FROM data_user WHERE email = '$email'");
    if ($query->num_rows > 0) {
        $row = $query->fetch_assoc();
        $newUserId = $row['id'] + 100000; // Generate unique userId by adding 100000

        // Update the userId field for the newly created user
        $updateStmt = $conn->prepare("UPDATE data_user SET user_id = ? WHERE id = ?");
        $updateStmt->bind_param("ii", $newUserId, $row['id']);
        $updateStmt->execute();
        $updateStmt->close();
    }

    // Successful signup
    echo json_encode(['message' => 'success', 'user_id' => $newUserId, 'token' => $token]);
} else {
    echo json_encode(['message' => 'error', 'error' => 'Database error: ' . $stmt->error]);
}

// Close the statement and connection
$stmt->close();
$conn->close();
?>
